@@ -10,7 +10,7 @@
 /* .Call calls */
 extern SEXP _STAREG_em_lfdr(void *, void *, void *, void *);
 
-static const R_CallMethodDef CallEntries[] = {
+/*static const R_CallMethodDef CallEntries[] = {
     {"_STAREG_em_lfdr", (DL_FUNC) &_STAREG_em_lfdr, 4},
     {NULL, NULL, 0}
 };
@@ -19,4 +19,4 @@ void R_init_STAREG(DllInfo *dll)
 {
     R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
     R_useDynamicSymbols(dll, FALSE);
-}
+}*/
